@@ -1,19 +1,18 @@
-
-from bergen.auths.types import HerreConfig
-from oauthlib.oauth2.rfc6749.errors import InvalidClientError
-from bergen.auths.base import AuthError, BaseAuthBackend
-from oauthlib.oauth2.rfc6749.clients.backend_application import BackendApplicationClient
-from requests_oauthlib.oauth2_session import OAuth2Session 
-from bergen.enums import ClientType
 import logging
 import time
+
+from bergen.auths.base import  BaseAuthBackend
 from bergen.console import console
+from oauthlib.oauth2.rfc6749.clients.backend_application import \
+    BackendApplicationClient
+from requests_oauthlib.oauth2_session import OAuth2Session
+
 logger = logging.getLogger(__name__)
 
 
 class ArnheimBackendOauth(BaseAuthBackend):
 
-    def __init__(self, config: HerreConfig, **kwargs) -> None:
+    def __init__(self, config, **kwargs) -> None:
         super().__init__(config , **kwargs)  
 
     def fetchToken(self, loop=None) -> str:
