@@ -7,9 +7,10 @@ class ArkitektConfig(BaseModel):
     secure: bool
     host: str
     port: int
+    internal: bool = False
 
     def __str__(self) -> str:
-        return f"{'Secure' if self.secure else 'Insecure'} Connection to Arkitekt on {self.host}:{self.port}"
+        return f"{'Internal' if self.internal else 'Public'} {'Secure' if self.secure else 'Insecure'} Connection to Arkitekt on {self.host}:{self.port}"
 
 
 class GrantType(str, Enum):
