@@ -1,9 +1,10 @@
 try:
     from PyQt5 import QtWidgets
     has_qt = True
+    qt_error = False
         
 except ImportError as e:
-    has_qt = False
+    has_qt = e
     QtWidgets = None
 
 
@@ -13,7 +14,6 @@ try:
         
 except ImportError as e:
     has_webview = False
-    QtWidgets = None
 
 
 class GraphicalBackend:
@@ -26,7 +26,8 @@ class GraphicalBackend:
 
     def __enter__(self):
         global has_qt
-        assert has_qt, "You cannot run with a Qt Backend if no QT Backend is installed. Please install PyQT5"
+        assert has_qt == True, f"You cannot run with a Qt Backend if no QT Backend is installed. Please install PyQT5 {str(has_qt)}"
+
         if QtWidgets.QApplication.instance() is None:
             # if it does not exist then a QApplication is created
             self.spawned_app = QtWidgets.QApplication([])
