@@ -47,12 +47,10 @@ class BaseProvider(Hookable):
     helperClass = None
 
 
-    def __init__(self, client: BaseBergen, provider: int = None, loop=None, **kwargs) -> None:
+    def __init__(self, client: BaseBergen, loop=None, **kwargs) -> None:
         super().__init__(**kwargs)
-        assert provider is not None, "Provider was set to none, this is weird!!"
-        self.arkitekt_provider = provider
         self.client = client
-        self.loop = loop or client.loop or asyncio.get_event_loop()
+        self.loop = loop or client.loop
 
         self.template_actorClass_map = {}
 
